@@ -3,7 +3,7 @@ package Hessian::Client;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('0.1.15');
+use version; our $VERSION = qv('0.2.0');
 
 use LWP::UserAgent;
 use HTTP::Request;
@@ -113,6 +113,14 @@ work. I am currently looking for publicly available or otherwise accesible
 Hessian services for testing.
 
 
+I probably should note that although the package was submitted under the name
+L<Hessian::Client>, the real work is actually done in
+L<Hessian::Translator|Hessian::Translator> and its associated subclasses and
+roles.  In fact, I will most likely change the package name to
+C<Hessian::Translator> and submit this as a separate module at
+some point in the near future.  
+
+
 =head1 INTERFACE
 
 =head2 new
