@@ -1,24 +1,33 @@
 package Hessian::Translator;
 
 use Moose;
-use version; our $VERSION = qv('0.0.2');
 
 use Module::Load;
 use YAML;
 use List::MoreUtils qw/any/;
 use Config;
+#use Smart::Comments;
 
 use Hessian::Exception;
-has 'is_big_endian'  => (is => 'ro', isa => 'Bool', default => 0);
-has 'original_position' => ( is => 'rw', isa => 'Int', default => 0 );
+
+has 'is_big_endian'     => ( is => 'ro', isa => 'Bool', default => 0 );
+has 'original_position' => ( is => 'rw', isa => 'Int',  default => 0 );
 has 'class_definitions' => ( is => 'rw', default => sub { [] } );
-has 'type_list'         => ( is => 'rw', default => sub { [] } );
-has 'reference_list'    => ( is => 'rw', default => sub { [] } );
-has 'input_string'      => ( is => 'rw', isa     => 'Str' );
-has 'version'           => ( is => 'ro', isa     => 'Int' );
+has 'type_list' => (    #{{{
+    is      => 'rw',
+    isa     => 'ArrayRef',
+    lazy    => 1,
+    default => sub { [] }
+);                      #}}}
+has 'reference_list' => ( is => 'rw', default => sub { [] } );
+has 'input_string' => (    #{{{
+    is  => 'rw',
+    isa => 'Str',
+);                         #}}}
+has 'version'     => ( is => 'ro', isa => 'Int' );
 has 'binary_mode' => ( is => 'ro', isa => 'Bool', default => 0 );
 has 'chunked'     => ( is => 'ro', isa => 'Bool', default => 0 );
-has 'serializer'  => (
+has 'serializer' => (
     is  => 'rw',
     isa => 'Bool',
 );
@@ -26,7 +35,7 @@ has 'in_interior' => ( is => 'rw', isa => 'Bool', default => 0 );
 
 before 'input_string' => sub {    #{{{
     my $self = shift;
-    if ( !$self->does('Hessian::Deserializer') ) {
+    if (  not $self->does('Hessian::Deserializer') ) {
         load 'Hessian::Deserializer';
         Hessian::Deserializer->meta()->apply($self);
     }
@@ -77,6 +86,8 @@ after 'version' => sub {    #{{{
 
 sub read_from_inputhandle {    #{{{
     my ( $self, $read_length ) = @_;
+    ### Reading from input handle: $read_length;
+
     my $input_handle = $self->input_handle();
     binmode( $input_handle, 'bytes' );
     my $original_pos            = $self->original_position();
@@ -86,6 +97,7 @@ sub read_from_inputhandle {    #{{{
       $current_position;
 
     my $remaining_length = length $remaining_string_buffer;
+    ### remaining: $remaining_length
     my $result;
     if ( $read_length > $remaining_length ) {
 
@@ -97,7 +109,8 @@ sub read_from_inputhandle {    #{{{
           . "read length: $read_length\nremaining: $remaining_length\n"
           . "string: "
           . $self->{input_string} . ".\n";
-#          print $message;
+
+        #          print $message;
 
         #        seek $input_handle, $original_pos, 0;
         # Throw an exception that will be caught by the caller
@@ -133,7 +146,7 @@ sub BUILD {    #{{{
     }
     $self->version();
     my $byteorder = $Config{byteorder};
-    $self->is_big_endian(1) if  $byteorder =~ /4321/;
+    $self->is_big_endian(1) if $byteorder =~ /4321/;
 
 }    #}}}
 
@@ -160,8 +173,9 @@ Hessian::Translator - Base class for Hessian serialization/deserialization.
 
 =head1 DESCRIPTION
 
-B<Hessian::Translator> is made to act as the base class (or whatever this is
-called in Moose terminology) for serialization/deserialization methods.  
+B<Hessian::Translator> and associated subclasses and roles provides
+serialization/deserialization of data and Perl datastructures into Hessian
+protocol.  
 
 On its own, this class really only provides some of the more basic functions
 required for Hessian processing such as the I<type list> for datatypes, the
@@ -173,11 +187,15 @@ is possibly to specialize the object for either Hessian 1.0 or Hessian 2.0
 processing and to selectively include methods for serialization and or
 deserialization.  
 
+
+
 =head1 INTERFACE
 
+
 =head2 BUILD
 
-Not to be called directly.  
+Not to be called directly.  Pod::Coverage complains if I don't have it in here
+though.
 
 
 =head2 new
@@ -242,8 +260,12 @@ the current object.
 
 =head2 read_from_inputhandle
 
+Reads a specified number of bytes from an input stream.
+
 =head2 set_current_position
 
+Set/reset the current position in an input stream.
+
 
 =head1 DEPENDENCIES
 
