@@ -9,8 +9,34 @@ use YAML;
 use Hessian::Exception;
 use Hessian::Simple;
 use Contextual::Return;
+#use Smart::Comments;
+
+sub assemble_class {    #{{{
+    ### assemble_class
+    my ( $self,             $args )       = @_;
+    my ( $class_definition, $class_type ) = @{$args}{qw/class_def type/};
+    my $datastructure = pop @{ $self->reference_list() } || $args->{data};
+    my $simple_obj = bless $datastructure, $class_type;
+    push @{ $self->reference_list() }, $simple_obj;
+
+    #    $self->reference_list()->[-1] = $simple_obj;
+    {
+        ## no critic
+        no strict 'refs';
+        push @{ $class_type . '::ISA' }, 'Hessian::Simple';
+        ## use critic
+    }
+    foreach my $field ( @{ $class_definition->{fields} } ) {
+        $simple_obj->meta()->add_attribute( $field, is => 'rw' );
+        my $value = $self->deserialize_data();
+        $simple_obj->$field($value);
+    }
+    return $simple_obj;
+
+}    #}}}
 
 sub read_typed_list_element {    #{{{
+    ### read_typed_list_element
     my ( $self, $type, $args ) = @_;
     my ( $element, $first_bit );
     if ( $args->{first_bit} ) {
@@ -52,6 +78,7 @@ sub read_typed_list_element {    #{{{
 }    #}}}
 
 sub read_list_type {    #{{{
+    ### read_list_type
     my $self        = shift;
     my $type_length = $self->read_from_inputhandle(1);
     my $type        = $self->read_string_handle_chunk($type_length);
@@ -59,6 +86,7 @@ sub read_list_type {    #{{{
 }    #}}}
 
 sub store_fetch_type {    #{{{
+    ### store_fetch_type
     my ( $self, $entity_type ) = @_;
     my $type;
     if ( $entity_type =~ /^([^\x00-\x0f].*)/ ) {
@@ -67,13 +95,14 @@ sub store_fetch_type {    #{{{
     }
     else {
         my $integer = unpack 'C*', $entity_type;
-        $type = $self->type_list()->[$integer];
+        $type = $self->type_list()->[$integer] if $integer;
 
     }
     return $type;
 }    #}}}
 
 sub store_class_definition {    #{{{
+    ### store_class_definition
     my ( $self, $class_type ) = @_;
     my $length           = $self->read_from_inputhandle(1);
     my $number_of_fields = $self->read_integer_handle_chunk($length);
@@ -93,22 +122,24 @@ sub store_class_definition {    #{{{
 }    #}}}
 
 sub read_hessian_chunk {    #{{{
+    ### read_hessian_chunk
     my ( $self, $args ) = @_;
     my ( $first_bit, $element );
-    my $end_symbol = $self->end_of_datastructure_symbol();
+
+    #    my $end_symbol = $self->end_of_datastructure_symbol();
     if ( 'HASH' eq ( ref $args ) and $args->{first_bit} ) {
         $first_bit = $args->{first_bit};
     }
     else {
         $first_bit = $self->read_from_inputhandle(1);
     }
-    EndOfInput::X->throw( 
-        error => 'Reached end of datastructure.' 
-    )  if $first_bit eq $self->end_of_datastructure_symbol() ;
+    EndOfInput::X->throw( error => 'Reached end of datastructure.' )
+      if $first_bit eq $self->end_of_datastructure_symbol();
     return $self->read_simple_datastructure($first_bit);
 }    #}}}
 
 sub fetch_class_for_data {    #{{{
+    ### fetch_class_for_data
     my $self                    = shift;
     my $length                  = $self->read_from_inputhandle(1);
     my $class_definition_number = $self->read_integer_handle_chunk($length);
@@ -117,6 +148,7 @@ sub fetch_class_for_data {    #{{{
 }    #}}}
 
 sub instantiate_class {    #{{{
+    ### instantiate_class
     my ( $self, $index ) = @_;
     my $class_definitions = $self->class_definitions;
     my $class_definition  = $self->class_definitions()->[$index];
@@ -130,28 +162,8 @@ sub instantiate_class {    #{{{
     );
 }    #}}}
 
-sub assemble_class {    #{{{
-    my ( $self,             $args )       = @_;
-    my ( $class_definition, $class_type ) = @{$args}{qw/class_def type/};
-    my $datastructure = $self->reference_list()->[-1] ;
-    my $simple_obj = bless $datastructure, $class_type;
-    $self->reference_list()->[-1] = $simple_obj;
-    {
-        ## no critic
-        no strict 'refs';
-        push @{ $class_type . '::ISA' }, 'Hessian::Simple';
-        ## use critic
-    }
-    foreach my $field ( @{ $class_definition->{fields} } ) {
-        $simple_obj->meta()->add_attribute( $field, is => 'rw' );
-        my $value = $self->deserialize_data();
-        $simple_obj->$field($value);
-    }
-    return $simple_obj;
-
-}    #}}}
-
 sub read_list_length {    #{{{
+    ### read_list_length
     my ( $self, $first_bit ) = @_;
 
     my $array_length;
@@ -170,10 +182,12 @@ sub read_list_length {    #{{{
     elsif ( $first_bit =~ /\x6c/ ) {
         $array_length = $self->read_integer_handle_chunk('I');
     }
+    ### found array length: $array_length
     return $array_length;
 }    #}}}
 
 sub write_hessian_chunk {    #{{{
+    ### write_hessian_chunk
     my ( $self, $element ) = @_;
     my $hessian_element;
     my $element_type = ref $element ? ref $element : \$element;
@@ -210,9 +224,11 @@ sub write_hessian_chunk {    #{{{
 }    #}}}
 
 sub write_composite_element {    #{{{
+    ### write_composite_element
     my ( $self, $datastructure ) = @_;
     my $element_type =
       ref $datastructure ? ref $datastructure : \$datastructure;
+    ### element type: $element_type
     my $hessian_string;
     switch ($element_type) {
         case /HASH/ {
@@ -263,42 +279,43 @@ sub read_composite_datastructure {    #{{{
     return $self->read_composite_data($first_bit);
 }    #}}}
 
-sub read_map_handle {    #{{{
-    my $self    = shift;
-    my $v1_type = $self->read_v1_type();
-    my ( $entity_type, $next_bit ) = @{$v1_type}{qw/type next_bit/};
-    my $type;
-    $type = $self->store_fetch_type($entity_type) if $entity_type;
-    my $key;
-    if ($next_bit) {
-        $key = $self->read_hessian_chunk( { first_bit => $next_bit } );
-    }
+#sub read_map_handle {    #{{{
+#    my $self    = shift;
+#    my $v1_type = $self->read_v1_type();
+#    my ( $entity_type, $next_bit ) = @{$v1_type}{qw/type next_bit/};
+#    my $type;
+#    $type = $self->store_fetch_type($entity_type) if $entity_type;
+#    my $key;
+#    if ($next_bit) {
+#        $key = $self->read_hessian_chunk( { first_bit => $next_bit } );
+#    }
 
-    # For now only accept integers or strings as keys
-    my @key_value_pairs;
-  MAPLOOP:
-    {
-        eval { $key = $self->read_hessian_chunk(); } unless $key;
-        last MAPLOOP if Exception::Class->caught('EndOfInput::X') or
-        Exception::Class->caught('MessageIncomplete::X');
-        my $value = $self->read_hessian_chunk();
-        push @key_value_pairs, $key => $value;
-        undef $key;
-        redo MAPLOOP;
-    }
+#    # For now only accept integers or strings as keys
+#    my @key_value_pairs;
+#  MAPLOOP:
+#    {
+#        eval { $key = $self->read_hessian_chunk(); } unless $key;
+#        last MAPLOOP
+#          if Exception::Class->caught('EndOfInput::X')
+#              or Exception::Class->caught('MessageIncomplete::X');
+#        my $value = $self->read_hessian_chunk();
+#        push @key_value_pairs, $key => $value;
+#        undef $key;
+#        redo MAPLOOP;
+#    }
 
-    # should throw an exception if @key_value_pairs has an odd number of
-    # elements
+#    # should throw an exception if @key_value_pairs has an odd number of
+#    # elements
 
-    my $datastructure = $self->reference_list()->[-1];
-    my $hash          = {@key_value_pairs};
-    foreach my $key ( keys %{$hash} ) {
-        $datastructure->{$key} = $hash->{$key};
-    }
-    my $map = defined $type ? bless $datastructure => $type : $datastructure;
-    return $map;
+#    my $datastructure = $self->reference_list()->[-1];
+#    my $hash          = {@key_value_pairs};
+#    foreach my $key ( keys %{$hash} ) {
+#        $datastructure->{$key} = $hash->{$key};
+#    }
+#    my $map = defined $type ? bless $datastructure => $type : $datastructure;
+#    return $map;
 
-}    #}}}
+#}    #}}}
 
 sub read_v1_type {    #{{{
     my ( $self, $list_bit ) = @_;
@@ -318,22 +335,25 @@ sub read_v1_type {    #{{{
     return { next_bit => $first_bit };
 }    #}}}
 
-sub read_remote_object {    #{{{
-    my $self        = shift;
-    my $remote_type = $self->read_v1_type()->{type};
-    $remote_type =~ s/\./::/g;
-    my $class_definition = {
-        type   => $remote_type,
-        fields => ['remote_url']
-    };
-    return $self->assemble_class(
-        {
-            type      => $remote_type,
-            data      => {},
-            class_def => $class_definition
-        }
-    );
-}    #}}}
+#sub read_remote_object {    #{{{
+#    my $self        = shift;
+#    ### read_remote_object
+#    my $remote_type = $self->read_v1_type()->{type};
+#    $remote_type =~ s/\./::/g;
+#    my $class_definition = {
+#        type   => $remote_type,
+#        fields => ['remote_url']
+#    };
+
+#    ### class definition: Dump($class_definition)
+#    return $self->assemble_class(
+#        {
+#            type      => $remote_type,
+#            data      => {},
+#            class_def => $class_definition
+#        }
+#    );
+#}    #}}}
 
 "one, but we're not the same";
 
